# Features to Beat SQL (absorbed)

See [docs/_archive/FEATURES_TO_BEAT_SQL_SUMMARY.md](../_archive/FEATURES_TO_BEAT_SQL_SUMMARY.md). Current status: [REF_22_PROJECT.md](../REF_22_PROJECT.md), [REF_12_IDEA.md](../REF_12_IDEA.md).
